@@ -14,6 +14,7 @@
 // app includes
 #include "basictypes.h"
 #include "debug_utils.h"
+#include "dialog_utils.h"
 #include "floatingtextwidget.h"
 #include "linkwidget.h"
 #include "listpopupmenu.h"
@@ -25,15 +26,9 @@
 
 // kde includes
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <kinputdialog.h>
-#endif
 
 // qt includes
 #include <QEvent>
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 #include <QPolygon>
 
 /**
@@ -254,9 +249,9 @@ void SignalWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
 /**
  * Loads a "signalwidget" XMI element.
  */
-bool SignalWidget::loadFromXMI(QDomElement & qElement)
+bool SignalWidget::loadFromXMI1(QDomElement & qElement)
 {
-    if(!UMLWidget::loadFromXMI(qElement))
+    if(!UMLWidget::loadFromXMI1(qElement))
         return false;
     m_Text = qElement.attribute(QLatin1String("signalname"));
     m_Doc = qElement.attribute(QLatin1String("documentation"));
@@ -287,7 +282,7 @@ bool SignalWidget::loadFromXMI(QDomElement & qElement)
         QString tag = element.tagName();
         if (tag == QLatin1String("floatingtext") || tag == QLatin1String("UML::FloatingTextWidget")) {
             m_pName = new FloatingTextWidget(m_scene, Uml::TextRole::Floating, m_Text, textId);
-            if(! m_pName->loadFromXMI(element)) {
+            if(! m_pName->loadFromXMI1(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pName;
                 m_pName = 0;
@@ -304,16 +299,16 @@ bool SignalWidget::loadFromXMI(QDomElement & qElement)
 /**
  * Creates the "signalwidget" XMI element.
  */
-void SignalWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
+void SignalWidget::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
 {
     QDomElement signalElement = qDoc.createElement(QLatin1String("signalwidget"));
-    UMLWidget::saveToXMI(qDoc, signalElement);
+    UMLWidget::saveToXMI1(qDoc, signalElement);
     signalElement.setAttribute(QLatin1String("signalname"), m_Text);
     signalElement.setAttribute(QLatin1String("documentation"), m_Doc);
     signalElement.setAttribute(QLatin1String("signaltype"), m_signalType);
     if (m_pName && !m_pName->text().isEmpty()) {
         signalElement.setAttribute(QLatin1String("textid"), Uml::ID::toString(m_pName->id()));
-        m_pName -> saveToXMI(qDoc, signalElement);
+        m_pName -> saveToXMI1(qDoc, signalElement);
     }
     qElement.appendChild(signalElement);
 }
@@ -328,19 +323,10 @@ void SignalWidget::slotMenuSelection(QAction* action)
     switch(sel) {
     case ListPopupMenu::mt_Rename:
         {
-            bool ok = false;
             QString name = m_Text;
-#if QT_VERSION >= 0x050000
-            name = QInputDialog::getText(Q_NULLPTR,
-                                         i18n("Enter signal name"),
-                                         i18n("Enter the signal name :"),
-                                         QLineEdit::Normal,
-                                         m_Text, &ok);
-#else
-            name = KInputDialog::getText(i18n("Enter signal name"),
-                                         i18n("Enter the signal name :"),
-                                         m_Text, &ok);
-#endif
+            bool ok = Dialog_Utils::askName(i18n("Enter signal name"),
+                                            i18n("Enter the signal name :"),
+                                            name);
             if (ok && name.length() > 0) {
                 setName(name);
             }
